@@ -7,7 +7,7 @@
 
 {- |
 Module      : Control.Concurrent.Async.Lifted
-Copyright   : Copyright (C) 2012-2015 Mitsutoshi Aoe
+Copyright   : Copyright (C) 2012-2017 Mitsutoshi Aoe
 License     : BSD-style (see the file LICENSE)
 Maintainer  : Mitsutoshi Aoe <maoe@foldr.in>
 Stability   : experimental
@@ -63,13 +63,15 @@ module Control.Concurrent.Async.Lifted
   , link, link2
 
     -- * Convenient utilities
-  , race, race_, concurrently, mapConcurrently, forConcurrently
+  , race, race_, concurrently
+  , mapConcurrently, mapConcurrently_
+  , forConcurrently, forConcurrently_
   , Concurrently(..)
   ) where
 
 import Control.Applicative
 import Control.Concurrent (threadDelay)
-import Control.Monad ((>=>), forever, liftM)
+import Control.Monad ((>=>), forever, liftM, void)
 import GHC.IO (unsafeUnmask)
 import Prelude hiding (mapM)
 
@@ -81,6 +83,7 @@ import qualified Control.Concurrent.Async as A
 import qualified Control.Exception.Lifted as E
 
 #if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ < 710
+import Data.Foldable
 import Data.Traversable
 #endif
 #if !MIN_VERSION_base(4, 8, 0)
@@ -367,6 +370,14 @@ mapConcurrently
   -> m (t b)
 mapConcurrently f = runConcurrently . traverse (Concurrently . f)
 
+-- | Generalized version of 'A.mapConcurrently_'.
+mapConcurrently_
+  :: (Foldable t, MonadBaseControl IO m)
+  => (a -> m b)
+  -> t a
+  -> m ()
+mapConcurrently_ f = runConcurrently . foldMap (Concurrently . void . f)
+
 -- | Generalized version of 'A.forConcurrently'.
 forConcurrently
   :: (Traversable t, MonadBaseControl IO m)
@@ -375,6 +386,14 @@ forConcurrently
   -> m (t b)
 forConcurrently = flip mapConcurrently
 
+-- | Generalized version of 'A.forConcurrently_'.
+forConcurrently_
+  :: (Foldable t, MonadBaseControl IO m)
+  => t a
+  -> (a -> m b)
+  -> m ()
+forConcurrently_ = flip mapConcurrently_
+
 -- | Generalized version of 'A.Concurrently'.
 --
 -- A value of type @'Concurrently' m a@ is an IO-based operation that can be
